==> haskell-js-jquery-3.2.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-js-jquery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: js-jquery
version: 3.2.1
id: js-jquery-3.2.1-GtxtZ651RlV17366fNzcXt
key: js-jquery-3.2.1-GtxtZ651RlV17366fNzcXt
license: MIT
copyright: Neil Mitchell 2014-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/js-jquery#readme
synopsis: Obtain minified jQuery code
description:
    This package bundles the minified <http://jquery.com/ jQuery> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jQuery version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).
category: Javascript
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Language.Javascript.JQuery
hidden-modules: Paths_js_jquery
abi: 913bdb7efe6dad657aa5f04b79cbd353
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/js-jquery-3.2.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/js-jquery-3.2.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/js-jquery-3.2.1
hs-libraries: HSjs-jquery-3.2.1-GtxtZ651RlV17366fNzcXt
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
haddock-html: /usr/share/doc/haskell-js-jquery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-jquery-3.2.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-js-jquery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: js-jquery
version: 3.2.1
id: js-jquery-3.2.1-GyZ9FJonY6dAAMhwJ2fANo
key: js-jquery-3.2.1-GyZ9FJonY6dAAMhwJ2fANo
license: MIT
copyright: Neil Mitchell 2014-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/js-jquery#readme
synopsis: Obtain minified jQuery code
description:
    This package bundles the minified <http://jquery.com/ jQuery> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jQuery version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).
category: Javascript
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Language.Javascript.JQuery
hidden-modules: Paths_js_jquery
abi: 4d58de2c3802cae449ee216ff9fea033
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/js-jquery-3.2.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/js-jquery-3.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-js-jquery
hs-libraries: HSjs-jquery-3.2.1-GyZ9FJonY6dAAMhwJ2fANo
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
haddock-interfaces: /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
haddock-html: /usr/share/doc/haskell-js-jquery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
